import { createReducer, on } from '@ngrx/store';

import {
  initialState,
  adapterChatting,
  adapterEventList,
  Chatting,
  adapterFileInfoList,
  adapterFileInfoCheckList
} from './state';

import * as roomActions from '../room/actions';
import {
  eventsSuccess,
  eventsFailure,
  readSuccess,
  fileInfosSuccess,
  fileInfosFailure,
  addEvent
} from './actions';

export const reducer = createReducer(
  initialState,

  on(roomActions.selectedRoom, (state, action) => {
    return {
      ...state,
      activeRoomId: action.roomId
    };
  }),

  on(roomActions.clearSelectedRoom, (state, action) => {
    if (action.roomId === state.activeRoomId) {
      return {
        ...state,
        activeRoomId: null
      };
    } else {
      return state;
    }
  }),

  on(eventsSuccess, (state, action) => {
    const roomId = action.res.roomId;

    const chatting = state.chattings.entities[roomId] || {};
    let trgtChatting: Chatting = {
      roomId,

      eventListProcessing: false,
      eventList: adapterEventList.getInitialState(),
      eventStatus: null,
      remainEvent: false,

      fileInfoListProcessing: false,
      fileInfoList: adapterFileInfoList.getInitialState(),
      fileInfoCheckList: adapterFileInfoCheckList.getInitialState(),
      fileInfoSyncDate: '',
      ...chatting
    };

    trgtChatting = {
      ...trgtChatting,
      eventList: adapterEventList.upsertMany(action.eventInfoList, {
        ...trgtChatting.eventList
      }),
      eventStatus: action.res,
      remainEvent: action.remainEvent,
      eventListProcessing: false
    };

    return {
      ...state,
      chattings: adapterChatting.upsertOne(trgtChatting, {
        ...state.chattings
      })
    };
  }),

  on(eventsFailure, (state, action) => {
    const roomId = action.roomId;

    const chatting = state.chattings.entities[roomId];
    let trgtChatting: Chatting;
    if (!!chatting) {
      trgtChatting = {
        ...chatting,
        eventListProcessing: false
      };
    }

    return {
      ...state,
      chattings: adapterChatting.upsertOne(trgtChatting, {
        ...state.chattings
      })
    };
  }),

  on(fileInfosSuccess, (state, action) => {
    const roomId = action.res?.roomId;

    if (!roomId) {
      return state;
    }

    const chatting = state.chattings.entities[roomId] || {};
    let trgtChatting: Chatting = {
      roomId,

      eventListProcessing: false,
      eventList: adapterEventList.getInitialState(),
      eventStatus: null,
      remainEvent: false,

      fileInfoListProcessing: false,
      fileInfoList: adapterFileInfoList.getInitialState(),
      fileInfoCheckList: adapterFileInfoCheckList.getInitialState(),
      fileInfoSyncDate: '',
      ...chatting
    };

    const fileInfoList = action.fileInfoList;
    const fileInfoCheckList = action.fileInfoCheckList;

    trgtChatting = {
      ...trgtChatting,
      fileInfoList: !!fileInfoList
        ? adapterFileInfoList.upsertMany(fileInfoList, {
            ...trgtChatting.fileInfoList
          })
        : trgtChatting.fileInfoList,
      fileInfoCheckList: !!fileInfoCheckList
        ? adapterFileInfoCheckList.upsertMany(fileInfoCheckList, {
            ...trgtChatting.fileInfoCheckList
          })
        : trgtChatting.fileInfoCheckList,
      fileInfoListProcessing: false
    };

    return {
      ...state,
      chattings: adapterChatting.upsertOne(trgtChatting, {
        ...state.chattings
      })
    };
  }),

  on(fileInfosFailure, (state, action) => {
    const roomId = action.roomId;

    const chatting = state.chattings.entities[roomId];
    let trgtChatting: Chatting;
    if (!!chatting) {
      trgtChatting = {
        ...chatting,
        fileInfoListProcessing: false
      };
    }

    return {
      ...state,
      chattings: adapterChatting.upsertOne(trgtChatting, {
        ...state.chattings
      })
    };
  }),

  on(addEvent, (state, action) => {
    const roomId = action.roomId;
    const eventInfo = action.info;

    const chatting = state.chattings.entities[roomId];

    if (!!chatting) {
      return {
        ...state,
        chattings: adapterChatting.upsertOne(
          {
            ...chatting,
            eventList: adapterEventList.upsertOne(eventInfo, {
              ...chatting.eventList
            })
          },
          { ...state.chattings }
        )
      };
    } else {
      return state;
    }
  })
);
