import {
  EventJson,
  EventType,
  FileEventJson,
  FileType,
  VideoConferenceEventJson,
  VideoConferenceContentsType,
  MassTextEventJson,
  TranslationEventJson,
  MassTranslationEventJson,
  PlanEventJson,
  PlanContentType
} from '@ucap/protocol-event';

export class ChatUtil {
  public static convertFinalEventMessage(
    eventType: EventType,
    finalEventMessage: EventJson
  ): string | null {
    let eventMessage: string = null;

    switch (eventType) {
      case EventType.Join:
      case EventType.Exit:
      case EventType.ForcedExit:
      case EventType.RenameRoom:
      case EventType.NotificationForTimerRoom:
      case EventType.GuideForRoomTimerChanged:
        {
          /**
           * 해당 타입은 메시지를 갱신하지 않는다.
           * @description Edit with ui-chat > messages.component.ts
           */
        }
        break;
      case EventType.Sticker:
        {
          eventMessage = '스티커';
        }
        break;
      case EventType.File:
        {
          const m = finalEventMessage as FileEventJson;

          if (FileType.Image === m.fileType) {
            eventMessage = '이미지';
          } else {
            eventMessage = '첨부파일';
          }
        }
        break;
      case EventType.VideoConference:
        {
          const m = finalEventMessage as VideoConferenceEventJson;
          switch (m.contents) {
            case VideoConferenceContentsType.Now:
              eventMessage = '화상회의가 개설되었습니다.';
              break;
            case VideoConferenceContentsType.New:
              eventMessage = '화상회의가 등록되었습니다.';
              break;
            case VideoConferenceContentsType.Update:
              eventMessage = '화상회의가 수정되었습니다.';
              break;
            case VideoConferenceContentsType.Delete:
              eventMessage = '화상회의가 취소되었습니다.';
              break;
            default:
              eventMessage = '화상회의';
              break;
          }
        }
        break;
      case EventType.MassText:
        {
          const m = finalEventMessage as MassTextEventJson;
          eventMessage = m.content;
        }
        break;
      case EventType.Translation:
        {
          const m = finalEventMessage as TranslationEventJson;
          eventMessage = m.original;
        }
        break;
      case EventType.MassTranslation:
        {
          const m = finalEventMessage as MassTranslationEventJson;
          eventMessage = m.original;
        }
        break;
      case EventType.Plan:
        {
          const m = finalEventMessage as PlanEventJson;
          switch (m.contents) {
            case PlanContentType.New:
              eventMessage = '새로운 일정이 등록되었습니다.';
              break;
            case PlanContentType.Update:
              eventMessage = '일정이 수정되었습니다.';
              break;
            case PlanContentType.Delete:
              eventMessage = '일정이 취소되었습니다.';
              break;
            default:
              eventMessage = '일정이 업데이트 되었습니다.';
              break;
          }
        }
        break;
      case EventType.NotificationForiOSCapture:
        {
          const m = finalEventMessage as string;
          eventMessage = `${m}님이 대화내용을 캡쳐하였습니다.`;
        }
        break;

      case EventType.AllimElephant: // [daesang] 알림
        {
          eventMessage = '코끼리 알림';
        }
        break;
      case EventType.AllimTms: // [daesang] 알림
        {
          eventMessage = 'TMS 알림';
        }
        break;
      default:
        {
          const m = finalEventMessage as string;
          eventMessage = m;
        }

        break;
    }
    return eventMessage;
  }
}
