import { Component, OnInit, Input } from '@angular/core';
import {
  EventType,
  Info,
  EventJson,
  RenameRoomEventJson,
  GuideForRoomTimerChangedEventJson,
  JoinEventJson
} from '@ucap/protocol-event';
import { I18nService } from '@ucap/ng-i18n';

@Component({
  selector: 'ucap-chat-message-box-information',
  templateUrl: './information.component.html',
  styleUrls: ['./information.component.scss']
})
export class InformationComponent implements OnInit {
  @Input()
  message: Info<EventJson>;

  @Input()
  senderName?: string;

  EventType = EventType;

  constructor(private i18nService: I18nService) {}

  ngOnInit() {}

  protected getI18nForSir(names: string | string[]) {
    if (Array.isArray(names)) {
      return names.join(',');
    } else {
      return names;
    }
  }

  getOwnerForJoinEventJson() {
    return this.getI18nForSir(
      (this.message.sentMessageJson as JoinEventJson).owner
    );
  }
  getInviterForJoinEventJson() {
    return this.getI18nForSir(
      (this.message.sentMessageJson as JoinEventJson).inviter
    );
  }
  getCalcTimerForGuideForRoomTimerChanged() {
    const millisec =
      Number(
        (this.message.sentMessageJson as GuideForRoomTimerChangedEventJson).time
      ) * 1000;
    const langs = this.i18nService.t([
      'common.units.hourFrom',
      'common.units.minute',
      'common.units.second'
    ]);

    switch (millisec) {
      case 5000:
        return `5 ${langs['common.units.second']}`;
      case 10000:
        return `10 ${langs['common.units.second']}`;
      case 30000:
        return `30 ${langs['common.units.second']}`;
      case 60000:
        return `1 ${langs['common.units.minute']}`;
      case 300000:
        return `5 ${langs['common.units.minute']}`;
      case 600000:
        return `10 ${langs['common.units.minute']}`;
      case 1800000:
        return `30 ${langs['common.units.minute']}`;
      case 3600000:
        return `1 ${langs['common.units.hourFrom']}`;
      case 21600000:
        return `6 ${langs['common.units.hourFrom']}`;
      case 43200000:
        return `12 ${langs['common.units.hourFrom']}`;
      case 86400000:
        return `24 ${langs['common.units.hourFrom']}`;
      default:
        return `0 ${langs['common.units.second']}`;
    }
  }

  getRequesterForRenameRoom() {
    return (this.message.sentMessageJson as RenameRoomEventJson).requester;
  }
  getRoomNameForRenameRoom() {
    return (this.message.sentMessageJson as RenameRoomEventJson).roomName;
  }
}
