import {
  Component,
  OnInit,
  Input,
  EventEmitter,
  Output,
  AfterViewInit,
  ElementRef
} from '@angular/core';
import { Info, TranslationEventJson } from '@ucap/protocol-event';

@Component({
  selector: 'ucap-chat-message-box-translation',
  templateUrl: './translation.component.html',
  styleUrls: ['./translation.component.scss']
})
export class TranslationComponent implements OnInit, AfterViewInit {
  @Input()
  message: Info<TranslationEventJson>;

  @Input()
  translationSimpleview: boolean;

  @Input()
  isMe: boolean;

  @Input()
  stickerUrl?: string;

  @Input()
  stickerDefaultImagePath: string;

  @Output()
  contextMenu = new EventEmitter<{
    event: MouseEvent;
    type: string;
  }>();

  @Output()
  openLink = new EventEmitter<string>();

  constructor(private elementRef: ElementRef) {}

  ngOnInit() {}

  ngAfterViewInit(): void {
    if (
      !!this.elementRef.nativeElement &&
      !!this.elementRef.nativeElement.querySelector('a')
    ) {
      const elements = this.elementRef.nativeElement.querySelectorAll('a');
      elements.forEach((element) => {
        element.addEventListener('click', this.onClickEvent.bind(this));
      });
    }
  }

  onClickEvent(event: MouseEvent) {
    this.openLink.emit((event.target as HTMLAnchorElement).text);
  }

  onContextMenuMessage(event: MouseEvent, type: string) {
    this.contextMenu.emit({ event, type });
  }
}
