import { moduleMetadata } from '@storybook/angular';
import { action } from '@storybook/addon-actions';
import { linkTo } from '@storybook/addon-links';

import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

import { UserInfoSS } from '@ucap/protocol-query';

import { OrganizationUiModule } from '../organization-ui.module';

import { ProfileImage01Component } from './profile-image-01.component';
import { RoleCode } from '@ucap/protocol-authentication';
import { CallMode, EmployeeType, StatusCode } from '@ucap/core';
import {
  StatusBulkInfo,
  TerminalStatusInfo,
  TerminalStatusNumber
} from '@ucap/protocol-status';
import { WorkStatusType } from '@ucap/protocol';

const userInfo: UserInfoSS = {
  seq: '1234',
  name: '사용자1',
  profileImageFile: '사진파일',
  grade: '직급',
  intro: '업무소개',
  companyCode: '기관코드',
  hpNumber: '핸드폰번호',
  lineNumber: '내선번호',
  email: '이메일',
  isMobile: true,
  /**  */
  deptName: '부서명',
  /**  */
  order: '조회순서',

  isActive: true,
  roleCd: RoleCode.Self,
  employeeNum: 'A34567',
  madn: 'MADN',
  hardSadn: 'HARDPHONE_SADN',
  fmcSadn: 'FMC_SADN',
  callMode: CallMode.C2C,
  nameEn: '사용자명(영어)',
  nameCn: '사용자명(중국어)',
  gradeEn: '직급(영어)',
  gradeCn: '직급(중국어)',
  deptNameEn: '부서명(영어)',
  deptNameCn: '부서명(중국어)',
  deptSeq: 12345,
  isPrivacyAgree: true,
  isValidLogin: true,
  employeeType: EmployeeType.Regular
};

const presenceInfo: StatusBulkInfo = {
  userSeq: 'A53445',
  pcStatus: StatusCode.OnLine,
  phoneStatus: StatusCode.OnLine,
  mobileStatus: StatusCode.OnLine,
  conferenceStatus: StatusCode.OnLine,
  statusMessage: StatusCode.OnLine,
  mobileConferenceStatus: StatusCode.OnLine,
  imessengerStatus: StatusCode.OnLine,
  terminalStatus: TerminalStatusInfo.Alerting,
  terminalStatusNumber: TerminalStatusNumber.Alerting,
  workstatus: WorkStatusType.Work
};

export default {
  title: 'ui-organization::ProfileImage01Component',
  component: ProfileImage01Component,
  decorators: [
    moduleMetadata({
      imports: [BrowserModule, BrowserAnimationsModule, OrganizationUiModule],
      providers: []
    })
  ]
};

export const Default = () => ({
  component: ProfileImage01Component,
  props: {
    userInfo,
    presenceInfo
  }
});
